<?php

/**
 * @file
 * The template for the detail view of the Smart Glossary
 *
 * available variables:
 * - $base_path
 *     The base path for the glossary page
 * - $visual_mapper_available bool
 *     TRUE if the Visual Mapper exists, FALSE if not
 * - $term object
 *     The term-object
 * - $visual_mapper_settings string
 *     The settings for the Visual Mapper in json format
 * - $current_language string
 *     The currently chosen language of the concepts
 */

global $base_url, $language;

$visual_mapper_args = array(
  'base_path' => $base_path,
  'visual_mapper_available' => $visual_mapper_available,
  'concept_uri' => (filter_var($_GET['uri'], FILTER_VALIDATE_URL) !== FALSE) ? filter_var($_GET['uri'], FILTER_VALIDATE_URL) : '',
  'visual_mapper_settings' => $visual_mapper_settings,
  'current_language' => $current_language,
);

?>
<div id="smart-glossary-detail">
  <?php if (empty($term->prefLabel)): ?>
    <h2><?php print $term->prefLabelDefault; ?></h2>
    <p><?php print t('No translation of this glossary term available in selected language'); ?></p>
  <?php else: ?>
    <!-- term title
    <h2><?php print $term->prefLabel; ?></h2>
    -->

    <!-- term synonyms -->
    <?php if (!empty($term->altLabels)): ?>
      <?php $count = count($term->altLabels); ?>
      <h3><?php print t('Synonyms'); ?></h3>
      <p class="synonyms">
        <?php for ($i = 0; $i < $count; $i++): ?>
          <?php print $term->altLabels[$i]; ?><?php if ($i < ($count - 1)): ?>, <?php endif; ?>
        <?php endfor; ?>
      </p>
    <?php endif; ?>

    <!-- term definitions -->
    <div class="definitions">
      <?php if (empty($term->definitions)): ?>
        <?php print t('No definition available'); ?>
      <?php else: ?>
        <?php if (!empty($term->definitions['internal'])): ?>
          <div class="internal">
            <h3><?php print t('Definition'); ?></h3>
            <?php foreach ($term->definitions['internal'] as $definition): ?>
              <p class="definition"><?php print $definition; ?></p>
            <?php endforeach; ?>
          </div>
        <?php endif; ?>
        <?php if (!empty($term->definitions['external'])): ?>
          <div class="external">
          <?php foreach ($term->definitions['external'] as $class => $resource): ?>
            <div class="<?php print $class; ?>">
            <?php if (!empty($resource)): ?>
              <h3><?php print $resource['title']; ?></h3>
              <?php foreach ($resource['content'] as $content): ?>
                <p class="definition"><?php print $content['definition']; ?></p>
                <?php $link = $content['source'] . (empty($content['label']) ? '' : ' - ' . $content['label']); ?>
                <p class="source"><?php print t('Source:'); ?> <?php print l($link, $content['url'], array('attributes' => array('target' => '_blank'))); ?></p>
              <?php endforeach; ?>
            <?php endif; ?>
            </div>
          <?php endforeach; ?>
          </div>
        <?php endif; ?>
      <?php endif; ?>
    </div>

    <?php print theme('smart_glossary_visual_mapper', $visual_mapper_args); ?>

    <!-- semantic relations -->
    <?php if (!empty($term->related) || !empty($term->broader) || !empty($term->narrower)): ?>
      <div class="semantic-relations">
        <?php if (!empty($term->related)): ?>
          <div class="related">
            <h3><?php print t('Related terms'); ?></h3>
            <?php $count = count($term->related); ?>
            <?php for ($i = 0; $i < $count; $i++): ?>
              <a href="<?php print $term->related[$i]['url']; ?>"><?php print $term->related[$i]['prefLabel']; ?></a><?php if ($i < ($count - 1)): ?>, <?php endif; ?>
            <?php endfor; ?>
          </div>
        <?php endif; ?>
				<?php if (!empty($term->broader)): ?>
          <div class="broader">
            <h3><?php print t('Broader terms'); ?></h3>
            <?php $count = count($term->broader); ?>
            <?php for ($i = 0; $i < $count; $i++): ?>
              <a href="<?php print $term->broader[$i]['url']; ?>"><?php print $term->broader[$i]['prefLabel']; ?></a><?php if ($i < ($count - 1)): ?>, <?php endif; ?>
            <?php endfor; ?>
          </div>
        <?php endif; ?>
				<?php if (!empty($term->narrower)): ?>
          <div class="narrower">
            <h3><?php print t('Narrower terms'); ?></h3>
            <?php $count = count($term->narrower); ?>
            <?php for ($i = 0; $i < $count; $i++): ?>
              <a href="<?php print $term->narrower[$i]['url']; ?>"><?php print $term->narrower[$i]['prefLabel']; ?></a><?php if ($i < ($count - 1)): ?>, <?php endif; ?>
            <?php endfor; ?>
          </div>
        <?php endif; ?>
      </div>
    <?php endif; ?>

  <?php endif; ?>
</div>
